/**********************************************************************
** Copyright (C) 2000 Trolltech AS.  All rights reserved.
**
** This file is part of Qt Palmtop Environment.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** See http://www.trolltech.com/gpl/ for GPL licensing information.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
**
**********************************************************************/
#include <qtoolbar.h>
#if defined(Q_WS_QWS) || defined(QWS)
#include <qpe/qpemenubar.h>
#else
#include <qmenubar.h>
#endif
#include <qpopupmenu.h>
#include <qpushbutton.h>
#include <qlcdnumber.h>
#include <qmessagebox.h>
#include <qtimer.h>
#include <qpalette.h>
#include <qapplication.h>
#include <qlayout.h>
#include <qlabel.h>

#include "sokoban.H"
#ifndef ZAURUS_SDK
#include "resource.h"
#include "config.h"
#else
#include <qpe/config.h>
#endif

#include <stdlib.h>
#include <time.h>

#ifndef ZAURUS_SDK
#include "sokoban.moc"
#endif

Sokoban::Sokoban( QWidget* parent, const char* name, WFlags f )
  : QMainWindow( parent, name, f )
{
    srand(::time(0));
    setCaption( tr("Sokoban") );
#ifndef ZAURUS_SDK
    setIcon( Resource::loadPixmap( "sokoban_icon" ) );
#endif

    field = new PlayField( this );
    setCentralWidget( field );
    field->show();

    createCollectionMenu();

#if defined(Q_WS_QWS) || defined(QWS)
    QPEMenuBar* menu = new QPEMenuBar(this);
#else
    QMenuBar* menu = menuBar();
#endif
    QPopupMenu *gameMenu = new QPopupMenu( 0, "game menu");

    gameMenu->insertItem(tr("Undo"),field,SLOT(undo()));
    gameMenu->insertItem(tr("Redo"),field,SLOT(redo()));

    gameMenu->insertSeparator();

    gameMenu->insertItem(tr("Next level"),field,SLOT(nextLevel()));
    gameMenu->insertItem(tr("Previous level"),field,SLOT(previousLevel()));

    gameMenu->insertItem(tr("Restart level"),field,SLOT(restartLevel()));
    gameMenu->insertItem( tr("Levels"),collection_ );

    animMenu = new QPopupMenu( 0, "anim menu");
    animMenu->setCheckable(true);
    connect(animMenu,SIGNAL(activated(int)),this,SLOT(updateAnimMenu(int)));
    connect(animMenu,SIGNAL(activated(int)),field,SLOT(changeAnim(int)));

    animMenu->insertItem(tr("Slow"),3);
    animMenu->insertItem(tr("Medium"),2);
    animMenu->insertItem(tr("Fast"),1);
    animMenu->insertItem(tr("Off"),0);
    checkedAnim_ = field->animDelay();
    updateAnimMenu(checkedAnim_);
    gameMenu->insertItem(tr("Animation"),animMenu);

    gameMenu->insertSeparator();
    gameMenu->insertItem( tr("Close"), this, SLOT( close() ) );
    menu->insertItem( tr("Game"), gameMenu );

    readConfig();
}

Sokoban::~Sokoban()
{
    writeConfig();
}


void Sokoban::writeConfig() const
{
    Config cfg("Sokoban");
    cfg.setGroup("Panel");
    cfg.writeEntry("Time", 1234);
    //field->writeConfig(cfg);
}

void Sokoban::readConfig()
{
    Config cfg("Sokoban");
    //field->readConfig(cfg);
    cfg.setGroup("Panel");
    //int s = cfg.readNumEntry("Time",-1);
}

void Sokoban::createCollectionMenu() {
  collection_ = new QPopupMenu(0,"collection menu");
  collection_->setCheckable(true);
  connect(collection_,
	  SIGNAL(activated(int)), 
	  this,
	  SLOT(changeCollection(int)));

  for (int i=0; i<internalCollections_.collections(); i++) {
    collection_->insertItem(internalCollections_[i]->name(), i);
  }
  checkedCollection_ = 0;

  Config cfg("Sokoban");
  cfg.setGroup("settings");
  int id = cfg.readNumEntry("collection", 10);

  currentCollection_ = 0;
  for (int i=0; i<internalCollections_.collections(); i++) {
    if (internalCollections_[i]->id() == id) currentCollection_ = i;
  }

  changeCollection(currentCollection_);
}

void
Sokoban::changeCollection(int id)
{
  collection_->setItemChecked(checkedCollection_, false);
  checkedCollection_ = id;
  collection_->setItemChecked(checkedCollection_, true);
  field->changeCollection(internalCollections_[id]);
}

void
Sokoban::updateAnimMenu(int id) {
  animMenu->setItemChecked(checkedAnim_, false);
  checkedAnim_ = id;
  animMenu->setItemChecked(checkedAnim_, true);
}
